@@ -40,7 +40,6 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <totem-pl-parser.h>
-#include <totem-scrsaver.h>
 
 #include <dbus/dbus-glib.h>
 
@@ -89,8 +88,6 @@ typedef enum {
 #define TOTEM_IS_EMBEDDED_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_EMBEDDED))
 #define TOTEM_EMBEDDED_GET_CLASS(o)(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_EMBEDDED, TotemEmbeddedClass))
 
-typedef GObjectClass TotemEmbeddedClass;
-
 typedef struct {
 	char *uri;
 	char *subtitle;
@@ -99,8 +96,12 @@ typedef struct {
 	int starttime;
 } TotemPlItem;
 
+typedef struct {
+	GtkApplicationClass parent;
+} TotemEmbeddedClass;
+
 typedef struct _TotemEmbedded {
-	GObject parent;
+	GtkApplication parent;
 
 	DBusGConnection *conn;
 	GtkWidget *window;
@@ -108,7 +109,6 @@ typedef struct _TotemEmbedded {
 	GtkWidget *pp_button;
 	GtkWidget *pp_fs_button;
 	TotemStatusbar *statusbar;
-	TotemScrsaver *scrsaver;
 	int width, height;
         char *user_agent;
 	const char *mimetype;
@@ -123,6 +123,7 @@ typedef struct _TotemEmbedded {
 	BaconVideoWidget *bvw;
 	TotemStates state;
 	GdkCursor *cursor;
+	guint inhibit_id;
 
 	/* Playlist, a GList of TotemPlItem */
 	GList *playlist, *current;
@@ -176,7 +177,7 @@ enum
 	TOTEM_EMBEDDED_UNKNOWN_COMMAND
 };
 
-G_DEFINE_TYPE (TotemEmbedded, totem_embedded, G_TYPE_OBJECT);
+G_DEFINE_TYPE (TotemEmbedded, totem_embedded, GTK_TYPE_APPLICATION);
 static void totem_embedded_init (TotemEmbedded *emb) { }
 
 static gboolean totem_embedded_do_command (TotemEmbedded *emb, const char *command, GError **err);
@@ -377,8 +378,19 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 		break;
 	}
 
-	if (emb->scrsaver != NULL)
-		totem_scrsaver_set_state (emb->scrsaver, (state == TOTEM_STATE_PLAYING) ? FALSE : TRUE);
+	if (state == TOTEM_STATE_PLAYING) {
+		if (emb->inhibit_id == 0) {
+			emb->inhibit_id = gtk_application_inhibit (GTK_APPLICATION (emb),
+								   NULL,
+								   GTK_APPLICATION_INHIBIT_IDLE,
+								   _("Playing a movie"));
+		}
+	} else {
+		if (emb->inhibit_id != 0) {
+			gtk_application_uninhibit (GTK_APPLICATION (emb), emb->inhibit_id);
+			emb->inhibit_id = 0;
+		}
+	}
 	gtk_image_set_from_icon_name (GTK_IMAGE (image), id, GTK_ICON_SIZE_MENU);
 	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (emb->pp_fs_button), id);
 
@@ -439,7 +451,8 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 
 	bacon_video_widget_set_logo_mode (emb->bvw, FALSE);
 
-	retval = bacon_video_widget_open (emb->bvw, uri, emb->current_subtitle_uri, NULL);
+	retval = bacon_video_widget_open (emb->bvw, uri, NULL);
+	bacon_video_widget_set_text_subtitle (emb->bvw, emb->current_subtitle_uri);
 	g_free (uri);
 
 	/* FIXME we shouldn't even do that here */
@@ -1183,95 +1196,6 @@ on_play_pause (GtkWidget *widget, TotemEmbedded *emb)
 	}
 }
 
-static void
-popup_menu_position_func (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, GtkWidget *button)
-{
-	GtkWidget *widget = GTK_WIDGET (button);
-	GtkRequisition menu_req;
-	GtkTextDirection direction;
-	GtkAllocation allocation;
-
-	gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &menu_req);
-
-	direction = gtk_widget_get_direction (widget);
-
-	gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
-	gtk_widget_get_allocation (widget, &allocation);
-	*x += allocation.x;
-	*y += allocation.y;
-
-	if (direction == GTK_TEXT_DIR_LTR)
-		*x += MAX (allocation.width - menu_req.width, 0);
-	else if (menu_req.width > allocation.width)
-		*x -= menu_req.width - allocation.width;
-
-	/* This might not work properly if the popup button is right at the
-	 * top of the screen, but really, what are the chances */
-	*y -= menu_req.height;
-
-	*push_in = FALSE;
-}
-
-static void
-popup_menu_over_arrow (GtkToggleButton *button,
-		       GtkMenu *menu,
-		       GdkEventButton *event)
-{
-	gtk_menu_popup (menu, NULL, NULL,
-			(GtkMenuPositionFunc) popup_menu_position_func,
-			button,
-			event ? event->button : 0,
-			event ? event->time : gtk_get_current_event_time ());
-}
-
-static void
-on_popup_button_toggled (GtkToggleButton *button, TotemEmbedded *emb)
-{
-	GtkMenu *menu;
-
-	menu = GTK_MENU (gtk_builder_get_object (emb->menuxml, "menu"));
-
-	if (gtk_toggle_button_get_active (button) && !gtk_widget_get_visible (GTK_WIDGET (menu))) {
-		/* we get here only when the menu is activated by a key
-		 * press, so that we can select the first menu item */
-		popup_menu_over_arrow (button, menu, NULL);
-		gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
-	}
-}
-
-static gboolean
-on_popup_button_button_pressed (GtkToggleButton *button,
-				GdkEventButton *event,
-				TotemEmbedded *emb)
-{
-	if (event->button == 1) {
-		GtkMenu *menu;
-
-		menu = GTK_MENU (gtk_builder_get_object (emb->menuxml, "menu"));
-		if (!gtk_widget_get_visible (GTK_WIDGET (menu))) {
-			popup_menu_over_arrow (button, menu, event);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-		} else {
-			gtk_menu_popdown (menu);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-		}
-
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-static void
-on_popup_menu_unmap (GtkWidget *menu,
-		     TotemEmbedded *emb)
-{
-	GtkWidget *button;
-
-	button = GTK_WIDGET (gtk_builder_get_object (emb->xml, "popup_button"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-}
-
 static char *
 resolve_redirect (const char *old_mrl, const char *mrl)
 {
@@ -1499,7 +1423,6 @@ static void
 on_error_event (BaconVideoWidget *bvw,
 		char *message,
                 gboolean playback_stopped,
-		gboolean fatal,
 		TotemEmbedded *emb)
 {
 	if (playback_stopped) {
@@ -1528,11 +1451,6 @@ on_error_event (BaconVideoWidget *bvw,
 		}
 	}
 
-	if (fatal) {
-		/* FIXME: report error back to plugin */
-		exit (1);
-	}
-
 	totem_embedded_set_error (emb, BVW_ERROR_GENERIC, message);
 	totem_embedded_set_error_logo (emb, NULL);
 }
@@ -1579,7 +1497,7 @@ on_tick (GtkWidget *bvw,
 }
 
 static void
-on_buffering (BaconVideoWidget *bvw, guint percentage, TotemEmbedded *emb)
+on_buffering (BaconVideoWidget *bvw, gdouble percentage, TotemEmbedded *emb)
 {
 //	g_message ("Buffering: %d %%", percentage);
 }
@@ -1623,13 +1541,6 @@ property_notify_cb_volume (BaconVideoWidget *bvw,
 static gboolean
 on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
-	/* HACK: we want the behaviour you get with the middle button, so we
-	 * mangle the event.  clicking with other buttons moves the slider in
-	 * step increments, clicking with the middle button moves the slider to
-	 * the location of the click.
-	 */
-	event->button = 2;
-
 	emb->seeking = TRUE;
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
 				      TRUE);
@@ -1640,9 +1551,6 @@ on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 static gboolean
 cb_on_seek (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
-	/* HACK: see on_seek_start */
-	event->button = 2;
-
 	bacon_video_widget_seek (emb->bvw,
 		gtk_range_get_value (GTK_RANGE (widget)) / 65535, NULL);
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
@@ -1742,7 +1650,6 @@ totem_embedded_construct (TotemEmbedded *emb,
 {
 	GtkWidget *child, *container, *image;
 	GtkWidget *popup_button;
-	GtkWidget *menu;
 	GError *err = NULL;
 
 	emb->xml = totem_interface_load ("mozilla-viewer.ui", TRUE,
@@ -1868,11 +1775,15 @@ totem_embedded_construct (TotemEmbedded *emb,
 	g_signal_connect (G_OBJECT (emb->pp_button), "clicked",
 			  G_CALLBACK (on_play_pause), emb);
 
+	/* popup */
+	emb->menuxml = totem_interface_load ("mozilla-viewer.ui", TRUE,
+					     GTK_WINDOW (emb->window), emb);
+	g_assert (emb->menuxml);
+
 	popup_button = GTK_WIDGET (gtk_builder_get_object (emb->xml, "popup_button"));
-	g_signal_connect (G_OBJECT (popup_button), "toggled",
-			  G_CALLBACK (on_popup_button_toggled), emb);
-	g_signal_connect (G_OBJECT (popup_button), "button-press-event",
-			  G_CALLBACK (on_popup_button_button_pressed), emb);
+	gtk_menu_button_set_menu (GTK_MENU_BUTTON (popup_button),
+				  (GtkWidget *) gtk_builder_get_object (emb->menuxml, "menu"));
+	gtk_menu_button_set_direction (GTK_MENU_BUTTON (popup_button), GTK_ARROW_UP);
 
 	emb->volume = GTK_WIDGET (gtk_builder_get_object (emb->xml, "volume_button"));
 	gtk_scale_button_set_adjustment (GTK_SCALE_BUTTON (emb->fs->volume),
@@ -1884,13 +1795,8 @@ totem_embedded_construct (TotemEmbedded *emb,
 
 	emb->statusbar = TOTEM_STATUSBAR (gtk_builder_get_object (emb->xml, "statusbar"));
 
-	if (!emb->hidden) {
+	if (!emb->hidden)
 		gtk_widget_set_size_request (emb->window, width, height);
-		emb->scrsaver = totem_scrsaver_new ();
-		g_object_set (emb->scrsaver,
-			      "reason", _("Playing a movie"),
-			      NULL);
-	}
 
 #ifdef GNOME_ENABLE_DEBUG
 	child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "controls"));
@@ -1955,15 +1861,6 @@ totem_embedded_construct (TotemEmbedded *emb,
 		gtk_widget_show (emb->window);
 	}
 
-	/* popup */
-	emb->menuxml = totem_interface_load ("mozilla-viewer.ui", TRUE,
-					     GTK_WINDOW (emb->window), emb);
-	g_assert (emb->menuxml);
-
-	menu = GTK_WIDGET (gtk_builder_get_object (emb->menuxml, "menu"));
-	g_signal_connect (G_OBJECT (menu), "unmap",
-			  G_CALLBACK (on_popup_menu_unmap), emb);
-
 	/* Set the logo and the button glow */
 	if (!emb->hidden && emb->autostart == FALSE) {
 		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), TRUE);
@@ -2228,10 +2125,6 @@ int main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-#if !GLIB_CHECK_VERSION (2, 31, 0)
-	g_thread_init (NULL);
-#endif
-
 	g_set_application_name (_("Movie browser plugin"));
 	gtk_window_set_default_icon_name ("totem");
 
@@ -2356,7 +2249,10 @@ int main (int argc, char **argv)
 	gtk_settings = gtk_settings_get_default ();
 	g_object_set (G_OBJECT (gtk_settings), "gtk-application-prefer-dark-theme", TRUE, NULL);
 
-	emb = g_object_new (TOTEM_TYPE_EMBEDDED, NULL);
+	emb = g_object_new (TOTEM_TYPE_EMBEDDED,
+			    "application-id", svcname,
+			    "flags", G_APPLICATION_FLAGS_NONE,
+			    NULL);
 
 	emb->state = TOTEM_STATE_INVALID;
 	emb->width = -1;
