@@ -119,8 +119,10 @@ static const totemPluginMimeEntry kMimeTypes[] = {
   { "application/ogg", "ogg", NULL },
   { "audio/ogg", "oga", NULL },
   { "audio/x-ogg", "ogg", NULL },
+  { "audio/x-vorbis+ogg", "ogg", NULL },
   { "video/ogg", "ogv", NULL },
   { "video/x-ogg", "ogg", NULL },
+  { "video/x-theora+ogg", "ogg", NULL },
   { "application/annodex", "anx", NULL },
   { "audio/annodex", "axa", NULL },
   { "video/annodex", "axv", NULL },
@@ -131,7 +133,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
   { "application/x-nsv-vp3-mp3", "nsv", "video/x-nsv" },
   { "video/flv", "flv", "application/x-flash-video" },
   { "video/webm", "webm", NULL },
-  { "application/x-totem-plugin", "", "Totem Multimedia plugin" },
+  { "application/x-totem-plugin", "", "Videos multimedia plugin" },
   { "audio/midi", "mid, midi", NULL },
 #else
 #error Unknown plugin type
@@ -140,7 +142,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
 
 static const char kPluginDescription[] =
 #if defined(TOTEM_GMP_PLUGIN)
-  "Windows Media Player Plug-in 10 (compatible; Totem)";
+  "Windows Media Player Plug-in 10 (compatible; Videos)";
 #elif defined(TOTEM_NARROWSPACE_PLUGIN)
   "QuickTime Plug-in " TOTEM_NARROWSPACE_VERSION;
 #elif defined(TOTEM_VEGAS_PLUGIN)
@@ -148,7 +150,7 @@ static const char kPluginDescription[] =
 #elif defined(TOTEM_MULLY_PLUGIN)
   "DivX\xC2\xAE Web Player";
 #elif defined(TOTEM_CONE_PLUGIN)
-  "VLC Multimedia Plugin (compatible Totem " VERSION ")";
+  "VLC Multimedia Plugin (compatible Videos " VERSION ")";
 #else
 #error Unknown plugin type
 #endif
@@ -159,7 +161,7 @@ static const char kPluginLongDescription[] =
 #elif defined(TOTEM_VEGAS_PLUGIN)
   "Shockwave Flash 11.1 r102";
 #else
-  "The <a href=\"http://www.gnome.org/projects/totem/\">Totem</a> " PACKAGE_VERSION " plugin handles video and audio streams.";
+  "The <a href=\"http://www.gnome.org/\">Videos</a> " PACKAGE_VERSION " plugin handles video and audio streams.";
 #endif
 
 static const char kPluginUserAgent[] =
@@ -168,7 +170,7 @@ static const char kPluginUserAgent[] =
 #elif defined(TOTEM_GMP_PLUGIN)
   "Windows-Media-Player/10.00.00.4019";
 #elif defined(TOTEM_VEGAS_PLUGIN)
-  "Totem/"VERSION;
+  "Videos/"VERSION;
 #else
   "";
 #endif
@@ -2056,6 +2058,8 @@ totemPlugin::Init (NPMIMEType mimetype,
 		}
 		g_free (oldSrc);
 	}
+
+	mAutoPlay = FALSE;
 #endif
 
 #if 0 //def TOTEM_MULLY_PLUGIN
