@@ -36,7 +36,6 @@
 
 #ifdef GDK_WINDOWING_X11
 /* X11 headers */
-#include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 #endif
 
@@ -53,13 +52,6 @@
 
 static gboolean startup_called = FALSE;
 
-static void
-long_action (void)
-{
-	while (gtk_events_pending ())
-		gtk_main_iteration ();
-}
-
 /* Debug log message handler: discards debug messages unless Totem is run with TOTEM_DEBUG=1.
  * If we're building in the source tree, enable debug messages by default. */
 static void
@@ -82,9 +74,6 @@ app_init (Totem *totem, char **argv)
 {
 	char *sidebar_pageid;
 
-	/* Settings */
-	totem->settings = g_settings_new (TOTEM_GSETTINGS_SCHEMA);
-
 	/* Debug log handling */
 	g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, (GLogFunc) debug_handler, totem->settings);
 
@@ -94,6 +83,10 @@ app_init (Totem *totem, char **argv)
 		totem_action_exit (NULL);
 
 	totem->win = GTK_WIDGET (gtk_builder_get_object (totem->xml, "totem_main_window"));
+	gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (totem->win), TRUE);
+	g_object_bind_property (G_OBJECT (totem), "fullscreen",
+				G_OBJECT (totem->win), "show-menubar",
+				G_BINDING_INVERT_BOOLEAN);
 
 	/* Menubar */
 	totem_ui_manager_setup (totem);
@@ -116,16 +109,15 @@ app_init (Totem *totem, char **argv)
 	totem_session_setup (totem, argv);
 	totem_setup_file_monitoring (totem);
 	totem_setup_file_filters ();
-	totem_setup_play_disc (totem);
+	totem_app_menu_setup (totem);
 	totem_callback_connect (totem);
+
 	sidebar_pageid = totem_setup_window (totem);
 
-	/* Show ! gtk_main_iteration trickery to show all the widgets
-	 * we have so far */
+	/* Show ! */
 	if (optionstate.fullscreen == FALSE) {
 		gtk_widget_show (totem->win);
 		totem_gdk_window_set_waiting_cursor (gtk_widget_get_window (totem->win));
-		long_action ();
 	} else {
 		gtk_widget_realize (totem->win);
 	}
@@ -144,6 +136,8 @@ app_init (Totem *totem, char **argv)
 	}
 
 	/* The prefs after the video widget is connected */
+	totem->prefs_xml = totem_interface_load ("preferences.ui", TRUE, NULL, totem);
+
 	totem_setup_preferences (totem);
 
 	totem_setup_recent (totem);
@@ -171,7 +165,7 @@ app_init (Totem *totem, char **argv)
 	if (optionstate.fullscreen == FALSE)
 		gdk_window_set_cursor (gtk_widget_get_window (totem->win), NULL);
 
-	gtk_window_set_application (GTK_WINDOW (totem->win), totem->app);
+	gtk_window_set_application (GTK_WINDOW (totem->win), GTK_APPLICATION (totem));
 }
 
 static void
@@ -190,8 +184,6 @@ app_command_line (GApplication             *app,
 		  Totem                    *totem)
 {
 	GOptionContext *context;
-	GOptionGroup *baconoptiongroup;
-	GError *error = NULL;
 	int argc;
 	char **argv;
 
@@ -201,30 +193,16 @@ app_command_line (GApplication             *app,
 	memset (&optionstate, 0, sizeof (optionstate));
 
 	/* Options parsing */
-	context = g_option_context_new (N_("- Play movies and songs"));
-	baconoptiongroup = bacon_video_widget_get_option_group();
-	if (baconoptiongroup == NULL) {
-		g_warning ("Clutter or GTK+ failed to initialise properly");
-		g_option_context_free (context);
-		return 1;
-	}
-	g_option_context_add_main_entries (context, all_options, GETTEXT_PACKAGE);
-	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
-	g_option_context_add_group (context, baconoptiongroup);
-
-	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	/* Only add session options to the server process */
-	if (startup_called != FALSE)
-		totem_session_add_options (context);
-	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
-		g_print (_("%s\nRun '%s --help' to see a full list of available command line options.\n"),
-				error->message, argv[0]);
-		g_error_free (error);
+	context = totem_options_get_context ();
+	g_option_context_set_help_enabled (context, FALSE);
+	if (g_option_context_parse (context, &argc, &argv, NULL) == FALSE) {
 	        g_option_context_free (context);
 	        return 1;
 	}
 	g_option_context_free (context);
 
+	totem_options_process_early (totem, &optionstate);
+
 	/* Don't create another window if we're remote.
 	 * We can't use g_application_get_is_remote() because it's not registered yet */
 	if (startup_called != FALSE) {
@@ -234,8 +212,6 @@ app_command_line (GApplication             *app,
 		g_strfreev (optionstate.filenames);
 		optionstate.filenames = NULL;
 		startup_called = FALSE;
-	} else {
-		gtk_window_present_with_time (GTK_WINDOW (totem->win), GDK_CURRENT_TIME);
 	}
 
 	/* Now do something with it */
@@ -259,35 +235,35 @@ main (int argc, char **argv)
 	if (XInitThreads () == 0)
 	{
 		gtk_init (&argc, &argv);
-		g_set_application_name (_("Totem Movie Player"));
+		g_set_application_name (_("Videos"));
 		totem_action_error_and_exit (_("Could not initialize the thread-safe libraries."), _("Verify your system installation. Totem will now exit."), NULL);
 	}
 #endif
 
-#if !GLIB_CHECK_VERSION (2, 31, 0)
-	g_thread_init (NULL);
-#endif
 	g_type_init ();
 	gtk_init (&argc, &argv);
 
-	g_set_application_name (_("Totem Movie Player"));
+	g_set_prgname ("totem");
+	g_set_application_name (_("Videos"));
 	gtk_window_set_default_icon_name ("totem");
 	g_setenv("PULSE_PROP_media.role", "video", TRUE);
 
 	gtk_settings = gtk_settings_get_default ();
 	g_object_set (G_OBJECT (gtk_settings), "gtk-application-prefer-dark-theme", TRUE, NULL);
 
-
 	/* Build the main Totem object */
-	totem = g_object_new (TOTEM_TYPE_OBJECT, NULL);
+	totem = g_object_new (TOTEM_TYPE_OBJECT,
+			      "application-id", "org.gnome.Totem",
+			      "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
+			      NULL);
+	totem->settings = g_settings_new (TOTEM_GSETTINGS_SCHEMA);
 
-	totem->app = gtk_application_new ("org.gnome.Totem", G_APPLICATION_HANDLES_COMMAND_LINE);
-	g_signal_connect (G_OBJECT (totem->app), "startup",
+	g_signal_connect (G_OBJECT (totem), "startup",
 			  G_CALLBACK (app_startup), totem);
-	g_signal_connect (G_OBJECT (totem->app), "command-line",
+	g_signal_connect (G_OBJECT (totem), "command-line",
 			  G_CALLBACK (app_command_line), totem);
 
-	g_application_run (G_APPLICATION (totem->app), argc, argv);
+	g_application_run (G_APPLICATION (totem), argc, argv);
 
 	return 0;
 }
